==> wp-record-selector-1.0.3.tgz: package/src/RecordSelector.js <==
import React, { useState } from "react";
import { Input, Table, Spin, Button, Icon } from "antd";
import Highlighter from "react-highlight-words";
import "./RecordSelector.css";


function RecordSelector(props) {
 let {
  current, // Selected record
  onSelect, // hook to call when a record is selected
  dataSource, // data source
  rowKey, // Table RowKey, default = id
  message, // Spin message (looking to phase out the usage of this)
  columns, // Table column objects
  pagination, // Table pagenation override
  disableHighlightRecord, // Disable highlight selected record, default = disableHighlightRecord
  scroll, // Table scroll override
 } = props;
 let [search, setSearch] = useState("");
 let [searchColumn, setSearchColumn] = useState("");

 function handleReset(clearFilters) {
  clearFilters();
  setSearch("");
 }

 const handleSearch = (selectedKeys, confirm, dataIndex) => {
  confirm();
  setSearch(selectedKeys[0]);
  setSearchColumn(dataIndex);
 }
 
 const nullAsEmpty = (text) => {
  return text ? text : ''
 }

 // convert null to 0 
 const nullAsZero = (val) => {
  return val ? val : 0
 }

 function handleRowClassName(record, index) {
  let _rowKey = rowKey ? rowKey : "id";
  let _current = current ? current : {};
  return record[_rowKey] === _current[_rowKey]
   ? "SelectedRowStyle"
   : "DefaultRowStyle";
 }

 function handleRowSelect(record) {
  if (onSelect) {
   onSelect(record);
  }
 }

 function getColumnSearchProps(dataIndex) {
  let searchInput = null;
  return {
   filterDropdown: ({
    setSelectedKeys,
    selectedKeys,
    confirm,
    clearFilters,
   }) => (
    <React.Fragment style={{ padding: 8 }}>
     <Input
      ref={(node) => {
       searchInput = node;
      }}
      placeholder={`Search ${dataIndex}`}
      value={selectedKeys[0]}
      onChange={(e) => setSelectedKeys(e.target.value ? [e.target.value] : [])}
      onPressEnter={() => handleSearch(selectedKeys, confirm, dataIndex)}
      style={{ width: 188, marginBottom: 8, display: "block" }}
     />
     <Button
      type="primary"
      onClick={() => handleSearch(selectedKeys, confirm, dataIndex)}
      icon="search"
      size="small"
      style={{ width: 90, marginRight: 8 }}
     >
      Search
     </Button>
     <Button
      onClick={() => handleReset(clearFilters)}
      size="small"
      style={{ width: 90 }}
     >
      Reset
     </Button>
    </React.Fragment>
   ),
   filterIcon: (filtered) => (
    <Icon type="search" style={{ color: filtered ? "#1890ff" : undefined }} />
   ),
   onFilter: (value, record) =>
    nullAsEmpty(record[dataIndex])
     .toString()
     .toLowerCase()
     .includes(value.toLowerCase()),
   onFilterDropdownVisibleChange: (visible) => {},
  };
 }

 function getColumnRenderProps(dataIndex) {
  return {
   render: (text) =>
    searchColumn === dataIndex ? (
     <Highlighter
      highlightStyle={{ backgroundColor: "#ffc069", padding: 0 }}
      searchWords={[search]}
      autoEscape
      textToHighlight={text?text.toString():null}
     />
    ) : (
     text
    ),
  };
 }

 function getColumnSorterProps(dataIndex, type = "Text") {
  if (type === "Text")
   return {
    sorter: (a, b) =>
     nullAsEmpty(a[dataIndex]).localeCompare(nullAsEmpty(b[dataIndex])),
   };
  else
   return {
    sorter: (a, b) => nullAsZero(a[dataIndex]) - nullAsZero(b[dataIndex]),
   };
 }

 function appendColumnProps(column) {
  if (column.dataIndex) {
   let c = { ...column, ...getColumnSearchProps(column.dataIndex) };
   if (!column.render) c = { ...c, ...getColumnRenderProps(column.dataIndex) };
   if (!column.sorter)
    c = { ...c, ...getColumnSorterProps(column.dataIndex, column.type) };
   return c;
  } else return column;
 }

 let _columns = columns.map(appendColumnProps);

 return (
  <Spin tip={message} spinning={message ? true : false}>
   <Table
    {...props}
    scroll={scroll ? scroll : { y: "calc(100vh - 16em)" }}
    columns={_columns}
    rowKey="id"
    dataSource={dataSource}
    pagination={pagination ? pagination : false}
    rowClassName={disableHighlightRecord ? "" : handleRowClassName}
    size="small"
    style={{ marginBottom: "20px", paddingBottom: "20px" }}
    onRow={(record) => {
     return {
      onClick: () => {
       handleRowSelect(record);
      },
     };
    }}
   />
  </Spin>
 );
}

export default RecordSelector;

==> wp-record-selector-1.0.8.tgz: package/src/RecordSelector.js <==
import React, { useState } from "react";
import { Input, Table, Spin, Button, Icon } from "antd";
import Highlighter from "react-highlight-words";
import "./RecordSelector.css";


function RecordSelector(props) {
 let {
  current, // Selected record
  onSelect, // hook to call when a record is selected
  dataSource, // data source
  rowKey, // Table RowKey, default = id
  message, // Spin message (looking to phase out the usage of this)
  columns, // Table column objects
  pagination, // Table pagenation override
  disableHighlightRecord, // Disable highlight selected record, default = disableHighlightRecord
  scroll, // Table scroll override
 } = props;
 let [search, setSearch] = useState("");
 let [searchColumn, setSearchColumn] = useState("");

 function handleReset(clearFilters) {
  clearFilters();
  setSearch("");
 }

 const handleSearch = (selectedKeys, confirm, dataIndex) => {
  confirm();
  setSearch(selectedKeys[0]);
  setSearchColumn(dataIndex);
 }
 
 const nullAsEmpty = (text) => {
  return text ? text : ''
 }

 // convert null to 0 
 const nullAsZero = (val) => {
  return val ? val : 0
 }

 function handleRowClassName(record, index) {
  let _rowKey = rowKey ? rowKey : "id";
  let _current = current ? current : {};
  return record[_rowKey] === _current[_rowKey]
   ? "SelectedRowStyle"
   : "DefaultRowStyle";
 }

 function handleRowSelect(record) {
  if (onSelect) {
   onSelect(record);
  }
 }

 function getColumnSearchProps(dataIndex) {
  let searchInput = null;
  return {
   filterDropdown: ({
    setSelectedKeys,
    selectedKeys,
    confirm,
    clearFilters,
   }) => (
    <div style={{ padding: 8 }}>
     <Input
      ref={(node) => {
       searchInput = node;
      }}
      placeholder={`Search ${dataIndex}`}
      value={selectedKeys[0]}
      onChange={(e) => setSelectedKeys(e.target.value ? [e.target.value] : [])}
      onPressEnter={() => handleSearch(selectedKeys, confirm, dataIndex)}
      style={{ width: 188, marginBottom: 8, display: "block" }}
     />
     <Button
      type="primary"
      onClick={() => handleSearch(selectedKeys, confirm, dataIndex)}
      icon="search"
      size="small"
      style={{ width: 90, marginRight: 8 }}
     >
      Search
     </Button>
     <Button
      onClick={() => handleReset(clearFilters)}
      size="small"
      style={{ width: 90 }}
     >
      Reset
     </Button>
    </div>
   ),
   filterIcon: (filtered) => (
    <Icon type="search" style={{ color: filtered ? "#1890ff" : undefined }} />
   ),
   onFilter: (value, record) =>
    nullAsEmpty(record[dataIndex])
     .toString()
     .toLowerCase()
     .includes(value.toLowerCase()),
   onFilterDropdownVisibleChange: (visible) => {},
  };
 }

 function getColumnRenderProps(dataIndex) {
  return {
   render: (text) =>
    searchColumn === dataIndex ? (
     <Highlighter
      highlightStyle={{ backgroundColor: "#ffc069", padding: 0 }}
      searchWords={[search]}
      autoEscape
      textToHighlight={text?text.toString():null}
     />
    ) : (
     text
    ),
  };
 }

 function getColumnSorterProps(dataIndex, type = "Text") {
  if (type === "Text")
   return {
    sorter: (a, b) =>
     nullAsEmpty(a[dataIndex]).localeCompare(nullAsEmpty(b[dataIndex])),
   };
  else
   return {
    sorter: (a, b) => nullAsZero(a[dataIndex]) - nullAsZero(b[dataIndex]),
   };
 }

 function appendColumnProps(column) {
  if (column.dataIndex) {
   let c = { ...column, ...getColumnSearchProps(column.dataIndex) };
   if (!column.render) c = { ...c, ...getColumnRenderProps(column.dataIndex) };
   if (!column.sorter)
    c = { ...c, ...getColumnSorterProps(column.dataIndex, column.type) };
   return c;
  } else return column;
 }

 let _columns = columns.map(appendColumnProps);

 return (
  <Spin tip={message} spinning={message ? true : false}>
   <Table
    {...props}
    scroll={scroll ? scroll : { y: "calc(100vh - 16em)" }}
    columns={_columns}
    rowKey="id"
    dataSource={dataSource}
    pagination={pagination ? pagination : false}
    rowClassName={disableHighlightRecord ? "" : handleRowClassName}
    size="small"
    style={{ marginBottom: "20px", paddingBottom: "20px" }}
    onRow={(record) => {
     return {
      onClick: () => {
       handleRowSelect(record);
      },
     };
    }}
   />
  </Spin>
 );
}

module.exports.default = record-selector;
//export default RecordSelector;
